@@ -42,7 +42,7 @@ int gethostname(const char *, size_t);
 #endif
 
 
-static const char rcsid[]="$Id: reformime.c,v 1.36 2001/04/23 04:05:05 mrsam Exp $";
+static const char rcsid[]="$Id: reformime.c,v 1.37 2001/05/27 01:43:22 mrsam Exp $";
 
 void rfc2045_error(const char *errmsg)
 {
@@ -366,6 +366,24 @@ char	*dyn_disp_name=0;
 			;
 	}
 
+	/* Strip leading/trailing spaces */
+
+	p=filename_buf;
+	while (*p && isspace((int)(unsigned char)*p))
+		++p;
+
+	q=filename_buf;
+	while ((*q=*p) != 0)
+	{
+		++p;
+		++q;
+	}
+
+	for (p=q=filename_buf; *p; p++)
+		if (!isspace((int)(unsigned char)*p))
+			q=p+1;
+	*q=0;
+
 	disposition_filename_s=filename_buf;
 
 	if (ignore_filename)
